@@ -2,12 +2,12 @@ package Net::GitHub::V2::Commits;
 
 use Moose;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 use URI::Escape;
 
-with 'Net::GitHub::V2::Role';
+with 'Net::GitHub::V2::HasRepo';
 
 sub branch {
     my ( $self, $branch ) = @_;
@@ -97,4 +97,4 @@ Fayland Lam, C<< <fayland at gmail.com> >>
 Copyright 2009 Fayland Lam, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
\ No newline at end of file
+under the same terms as Perl itself.
