@@ -2,12 +2,12 @@ package Net::GitHub::V2::Network;
 
 use Moose;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 use URI::Escape;
 
-with 'Net::GitHub::V2::Role';
+with 'Net::GitHub::V2::HasRepo';
 
 sub network_meta {
     my ( $self ) = @_;
@@ -79,4 +79,4 @@ Fayland Lam, C<< <fayland at gmail.com> >>
 Copyright 2009 Fayland Lam, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
\ No newline at end of file
+under the same terms as Perl itself.
